mirror of
https://github.com/infiniteCable2/openpilot.git
synced 2026-08-02 13:29:28 +08:00
acd46aa94b
* modeld: Retain pre-20hz drive model support * Method not available anymore on OP * some fixes * Revert "Long planner get accel: new function args (#34288)" * Revert "Fix low-speed allow_throttle behavior in long planner (#33894)" * Revert "long planner: allow throttle reflects usage (#33792)" * Revert "Gate acceleration on model gas press predictions (#33643)" * Reapply "Gate acceleration on model gas press predictions (#33643)" This reverts commit 76b08e37cb8eb94266ad9f6fed80db227e7c3428. * Reapply "long planner: allow throttle reflects usage (#33792)" This reverts commit c75244ca4e9c48084b0205b7c871e1a4e0f4e693. * Reapply "Fix low-speed allow_throttle behavior in long planner (#33894)" This reverts commit b2b7d21b7b685a2785d1beede3d223f0bb954807. * Reapply "Long planner get accel: new function args (#34288)" This reverts commit 74dca2fccf4da59cc8ac62ba9c0ad10ba3fc264b. * don't need * retain snpe * wrong * they're symlinks * remove * put back into VCS * add back * don't include built * Refactor model runner retrieval with caching support Added caching for active model runner type via `ModelRunnerTypeCache` to enhance performance and avoid redundant checks. Introduced a `force_check` flag to bypass the cache when necessary. Updated related code to handle cache clearing during onroad transitions. * Update model runner determination logic with caching fix Enhances `get_active_model_runner` to utilize caching more effectively by ensuring type consistency and updating cache only when necessary. Also updates `is_snpe_model` to pass the `started` state to the runner determination function, improving behavior for dynamic checks. * default to none * enable in next PR * more --------- Co-authored-by: DevTekVE <devtekve@gmail.com>
48 lines
1.3 KiB
Common Lisp
48 lines
1.3 KiB
Common Lisp
#define UV_SIZE ((TRANSFORMED_WIDTH/2)*(TRANSFORMED_HEIGHT/2))
|
|
|
|
__kernel void loadys(__global uchar8 const * const Y,
|
|
__global float * out,
|
|
int out_offset)
|
|
{
|
|
const int gid = get_global_id(0);
|
|
const int ois = gid * 8;
|
|
const int oy = ois / TRANSFORMED_WIDTH;
|
|
const int ox = ois % TRANSFORMED_WIDTH;
|
|
|
|
const uchar8 ys = Y[gid];
|
|
const float8 ysf = convert_float8(ys);
|
|
|
|
// 02
|
|
// 13
|
|
|
|
__global float* outy0;
|
|
__global float* outy1;
|
|
if ((oy & 1) == 0) {
|
|
outy0 = out + out_offset; //y0
|
|
outy1 = out + out_offset + UV_SIZE*2; //y2
|
|
} else {
|
|
outy0 = out + out_offset + UV_SIZE; //y1
|
|
outy1 = out + out_offset + UV_SIZE*3; //y3
|
|
}
|
|
|
|
vstore4(ysf.s0246, 0, outy0 + (oy/2) * (TRANSFORMED_WIDTH/2) + ox/2);
|
|
vstore4(ysf.s1357, 0, outy1 + (oy/2) * (TRANSFORMED_WIDTH/2) + ox/2);
|
|
}
|
|
|
|
__kernel void loaduv(__global uchar8 const * const in,
|
|
__global float8 * out,
|
|
int out_offset)
|
|
{
|
|
const int gid = get_global_id(0);
|
|
const uchar8 inv = in[gid];
|
|
const float8 outv = convert_float8(inv);
|
|
out[gid + out_offset / 8] = outv;
|
|
}
|
|
|
|
__kernel void copy(__global float8 * inout,
|
|
int in_offset)
|
|
{
|
|
const int gid = get_global_id(0);
|
|
inout[gid] = inout[gid + in_offset / 8];
|
|
}
|